@@ -1,10 +1,11 @@
-`CGdisc` <-
+CGdisc <-
 function(X,L,K,K.family,Y){
 	
 	X<-as.matrix(X)
 	L<-as.matrix(L)
 	
 	p.values<-NULL
+	effects<-NULL
 	
 	for(i in 1:ncol(X)){
 		
@@ -20,16 +21,20 @@ function(X,L,K,K.family,Y){
 		glmK<-suppressWarnings(glm(K~X1+L,family=K.family,weights=mu.i))
 		fit.K<-fitted.values(glmK)
 		
-		
+		effects[i]<-summary(lm(Y.tilde~X1))$coefficients[2,1]
+
 		lambda<-mean((X1-mean(X1))*Y*exp(-coef(glmY)[2]*K)*K)/(fit.K*summary(glmK)$dispersion)
 		
-		
 		T.tilde<-(X1-mean(X1))*Y.tilde-lambda*(K-fit.K)*eps
 		T<-sum(T.tilde)
 		sigma<-var(T.tilde)
 		test.stat<-T^2/(length(eps)*sigma)
 		p.values[i]<-1-pchisq(test.stat,1)
 		}
-	return(p.values)
+		
+	final<-rbind(effects,p.values)
+	rownames(final)<-c("effect size","p values")
+	return(final)
+	
 	}
 
